@@ -1,12 +1,10 @@
-# Copyright 2009-2022 Joshua Bronson. All rights reserved.
+# Copyright 2009-2024 Joshua Bronson. All rights reserved.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-"""Set up Hypothesis."""
-
 from hypothesis import settings
 
 
-settings.register_profile('more-examples', max_examples=10_000, deadline=None)
+settings.register_profile('more-examples', deadline=None, max_examples=999, stateful_step_count=200)
